Index: bfd/cpu-xgate.c |
diff --git a/bfd/cpu-d30v.c b/bfd/cpu-xgate.c |
similarity index 68% |
copy from bfd/cpu-d30v.c |
copy to bfd/cpu-xgate.c |
index d528e9bf67bac34cbb9f4910cd7bdc228766577e..11653fa51a4d4475ad602300e6b6d0a9dd7a3d7b 100644 |
--- a/bfd/cpu-d30v.c |
+++ b/bfd/cpu-xgate.c |
@@ -1,6 +1,5 @@ |
-/* BFD support for the Mitsubishi D30V processor |
- Copyright 1997, 2002, 2005, 2007 Free Software Foundation, Inc. |
- Contributed by Martin Hunt (hunt@cygnus.com). |
+/* BFD support for the Freescale XGATE processor |
+ Copyright 2010, 2011, 2012 Free Software Foundation, Inc. |
This file is part of BFD, the Binary File Descriptor library. |
@@ -23,18 +22,19 @@ |
#include "bfd.h" |
#include "libbfd.h" |
-const bfd_arch_info_type bfd_d30v_arch = |
+const bfd_arch_info_type bfd_xgate_arch = |
{ |
- 32, /* Bits in a word. */ |
- 32, /* Bits in an address. */ |
- 8, /* Bits in a byte. */ |
- bfd_arch_d30v, |
- 0, |
- "d30v", |
- "d30v", |
- 4, /* Section alignment power. */ |
+ 16, /* 16 bits in a word. */ |
+ 32, /* 32 bits used as 16 bit address and PPAGE value. */ |
+ 8, /* 8 bits in a byte. */ |
+ bfd_arch_xgate, |
+ bfd_mach_xgate, |
+ "xgate", |
+ "xgate", |
+ 4, /* Section alignment power. */ |
TRUE, |
bfd_default_compatible, |
bfd_default_scan, |
+ bfd_arch_default_fill, |
0, |
}; |